@@ -37,16 +37,27 @@ search_cuts_srt <- function(x,
 	if (is.null(s@results$transcript.name)) 		{ stop("Data frame s@results does not contain column 'transcript.name'") 	}
 	
 	if (!is.null(cutSpanBeforesec)) 	{
-		s@cuts.span.beforesec       <- as.double(cutSpanBeforesec)
+		if (length(cutSpanBeforesec)!=1) {
+			stop("Parameter 'cutSpanBeforesec' needs to contain only one element as a numeric value.") 
+		}
+		if (!is.numeric(cutSpanBeforesec)) {
+			stop("Parameter 'cutSpanBeforesec' needs to be a numeric value.") 
+		}
+		s@cuts.span.beforesec       <- cutSpanBeforesec
 	}
-	if (!is.null(cutSpanAftersec)) {
-		s@cuts.span.aftersec        <- as.double(cutSpanAftersec)	
+	if (!is.null(cutSpanAftersec)) 	{
+		if (length(cutSpanAftersec)!=1) {
+			stop("Parameter 'cutSpanAftersec' needs to contain only one element as a numeric value.") 
+		}
+		if (!is.numeric(cutSpanAftersec)) {
+			stop("Parameter 'cutSpanAftersec' needs to be a numeric value.") 
+		}
+		s@cuts.span.aftersec       <- cutSpanAftersec
 	}
-	
 	#--- check if output folder is given
 	destination_folder <- NULL
 	if (!is.null(outputFolder)) {
-		destination_folder <- normalizePath(outputFolder)
+		destination_folder <- normalizePath(outputFolder, winslash = "/")
 		if (destination_folder!="") {
 			if (dir.exists(destination_folder)==FALSE) 	{
 				stop("Output folder does not exist.")
